#########
Changelog
#########


Version 0.0.4
=============

- Repair some bugs.
- Update to make it compatible with cvxpy >=1.1.0
- Implement Principal Component Regression for loadings matrix estimation.
- Add Akaike information criterion, Schwarz information criterion, R squared and adjusted R squared feature selection criterions in stepwise regression.


Version 0.0.3
=============

- Repair some bugs.
- Implement an option for building constraints common for all assets classes.


Version 0.0.2
=============

- Repair some bugs.


Version 0.0.1
=============

- Implement robust estimates and ewma estimates.
- Implement Black Litterman model and risk factors models.
- Implement mean risk optimization with 10 risk measures.
